Draw a Figure Label at a Standard Position
Arguments
- text
Label text.
- region
Character string specifying whether the label should be placed relative to the
"figure","plot", or"device".- pos
Character string giving the label position.
- cex
Optional text expansion factor.
- margin
Numeric margin used to offset the label from the selected boundary.
- ...
Additional arguments passed to
graphics::text().