Skip to contents

A lightweight wrapper around rgbif::derived_dataset() that combines one or more get_gbif() outputs into a citable derived dataset.

Usage

get_doi(
  gbifs = NULL,
  title = NULL,
  description = NULL,
  source_url = "https://example.com/",
  user = "",
  pwd = "",
  ...
)

Arguments

gbifs

getGBIF object or a list of getGBIF objects.

title

Character. String giving the title of the derived dataset.

description

Character. String describing the dataset.

source_url

Character. String pointing to the location where the derived dataset or workflow is documented.

user

Character. String with the GBIF username used to submit the request.

pwd

Character. String with the GBIF password used to submit the request.

...

Additional arguments passed to rgbif::derived_dataset().

Value

The object returned by rgbif::derived_dataset(), including the DOI request metadata generated by GBIF.

Details

See rgbif::derived_dataset() for GBIF requirements and the structure of the returned metadata.

References

Chamberlain, S., Oldoni, D., & Waller, J. (2022). rgbif: interface to the global biodiversity information facility API. 10.5281/zenodo.6023735

See also

The rgbif package for more general workflows to create GBIF derived datasets and DOIs.

Examples

if (FALSE) { # \dontrun{
# Download worldwide observations of Panthera tigris
# and Ailuropoda melanoleuca
obspt <- get_gbif("Panthera tigris")
obsam <- get_gbif("Ailuropoda melanoleuca")

# Retrieve a DOI for one get_gbif() output
get_doi(
       gbifs = obspt,
       title = "GBIF_test1",
       description = "A small example 1",
       source_url = "https://example.com/",
       user = "",
       pwd = ""
) # Use your own GBIF credentials here

# Retrieve a DOI for several get_gbif() outputs
get_doi(
       gbifs = list(obspt,obsam),
       title = "GBIF_test2",
       description = "A small example 2",
       source_url = "https://example.com/",
       user = "",
       pwd = ""
) # Use your own GBIF credentials here

} # }